package api

import "github.com/gin-gonic/gin"

type BizApi interface {
	NewsList(c *gin.Context)         //新闻列表
	NewsAdd(c *gin.Context)          //新闻新增
	NewsEdit(c *gin.Context)         //新闻编辑
	NewsDelete(c *gin.Context)       //新闻删除
	NewsCompare(c *gin.Context)      //新闻对比
	NewsPublish(c *gin.Context)      //新闻发布(订阅列表)
	NewsDraftList(c *gin.Context)    //草稿列表
	NewsDraftEdit(c *gin.Context)    //草稿编辑
	NewsDraftPublish(c *gin.Context) //草稿发布
	NewsDraftDelete(c *gin.Context)  //草稿删除
	NewsTag(c *gin.Context)          //新闻打标签
	NewsAsync(c *gin.Context)        //异步同步数据
	NewsAsyncBatch(c *gin.Context)   //一次性整批同步数据
	NewsPullNew(c *gin.Context)      //拉取新的数据
	QaList(c *gin.Context)           //Q&A列表
	QaAdd(c *gin.Context)            //Q&A新增
	QaEdit(c *gin.Context)           //Q&A编辑
	QaDelete(c *gin.Context)         //Q&A删除
	QaDraftList(c *gin.Context)      //Q&A草稿列表
	QaDraftEdit(c *gin.Context)      //Q&A草稿编辑
	QaDraftPublish(c *gin.Context)   //Q&A草稿发布
	QaDraftDelete(c *gin.Context)    //Q&A草稿删除
	SubListAll(c *gin.Context)       //全部订阅新闻
	SubListPushed(c *gin.Context)    //已推送订阅新闻
	SubListToday(c *gin.Context)     //今日订阅新闻
	SubAddNews(c *gin.Context)       //新增订阅新闻
	SubEditNews(c *gin.Context)      //编辑订阅新闻
	TagList(c *gin.Context)          //标签列表
	TagAdd(c *gin.Context)           //标签新增
	TagEdit(c *gin.Context)          //标签编辑
	TagDelete(c *gin.Context)        //标签删除
}
